@@ -1,222 +1,237 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="el">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="el">
+<context>
+    <name>Cmd</name>
+    <message>
+        <location filename="../src/cmd.cpp" line="70"/>
+        <source>Administrator Access Required</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/cmd.cpp" line="71"/>
+        <source>This operation requires administrator privileges. Please restart the application and enter your password when prompted.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../mainwindow.ui" line="14"/>
-        <location filename="../mainwindow.cpp" line="375"/>
+        <location filename="../src/mainwindow.ui" line="14"/>
+        <location filename="../src/mainwindow.cpp" line="378"/>
         <source>MX Service Manager</source>
         <translation>MX Διαχειριστής υπηρεσιών</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="26"/>
-        <location filename="../mainwindow.cpp" line="157"/>
-        <location filename="../mainwindow.cpp" line="390"/>
+        <location filename="../src/mainwindow.ui" line="26"/>
+        <location filename="../src/mainwindow.cpp" line="160"/>
+        <location filename="../src/mainwindow.cpp" line="394"/>
         <source>&amp;Enable at boot</source>
         <translation>Ενερ&amp;γοποίηση στην εκκίνηση</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="62"/>
+        <location filename="../src/mainwindow.ui" line="62"/>
         <source>About this application</source>
         <translation>Περί της εφαρμογής</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="65"/>
+        <location filename="../src/mainwindow.ui" line="65"/>
         <source>&amp;About...</source>
         <translation>&amp;Περί...</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="71"/>
+        <location filename="../src/mainwindow.ui" line="71"/>
         <source>Alt+B</source>
         <translation>Alt+B</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="125"/>
+        <location filename="../src/mainwindow.ui" line="125"/>
         <source>Display help </source>
         <translation>Εμφάνιση βοήθειας </translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="128"/>
+        <location filename="../src/mainwindow.ui" line="128"/>
         <source>&amp;Help</source>
         <translation>&amp;Βοήθεια</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="134"/>
+        <location filename="../src/mainwindow.ui" line="134"/>
         <source>Alt+H</source>
         <translation>Alt+H</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="166"/>
+        <location filename="../src/mainwindow.ui" line="166"/>
         <source>Quit application</source>
         <translation>Κλείσιμο εφαρμογής</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="169"/>
+        <location filename="../src/mainwindow.ui" line="169"/>
         <source>&amp;Close</source>
         <translation>&amp;Κλείσιμο</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="175"/>
+        <location filename="../src/mainwindow.ui" line="175"/>
         <source>Alt+N</source>
         <translation>Alt+N</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="216"/>
-        <location filename="../mainwindow.cpp" line="139"/>
+        <location filename="../src/mainwindow.ui" line="216"/>
+        <location filename="../src/mainwindow.cpp" line="142"/>
         <source>&amp;Stop</source>
         <translation>Δια&amp;κοπή</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="230"/>
-        <location filename="../mainwindow.cpp" line="319"/>
+        <location filename="../src/mainwindow.ui" line="230"/>
+        <location filename="../src/mainwindow.cpp" line="322"/>
         <source>All services</source>
         <translation>Όλες οι υπηρεσίες</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="235"/>
-        <location filename="../mainwindow.cpp" line="320"/>
+        <location filename="../src/mainwindow.ui" line="235"/>
+        <location filename="../src/mainwindow.cpp" line="323"/>
         <source>Running services</source>
         <translation>Υπηρεσίες σε λειτουργία</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="240"/>
-        <location filename="../mainwindow.cpp" line="321"/>
+        <location filename="../src/mainwindow.ui" line="240"/>
+        <location filename="../src/mainwindow.cpp" line="324"/>
         <source>Services enabled at boot</source>
         <translation>Ενεργοποιημένες υπηρεσίες στην εκκίνηση</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="245"/>
-        <location filename="../mainwindow.cpp" line="322"/>
+        <location filename="../src/mainwindow.ui" line="245"/>
+        <location filename="../src/mainwindow.cpp" line="325"/>
         <source>Services disabled at boot</source>
         <translation>Απενεργοποιημένες υπηρεσίες στην εκκίνηση</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="281"/>
+        <location filename="../src/mainwindow.ui" line="281"/>
         <source>search</source>
         <translation>αναζήτηση</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="291"/>
-        <location filename="../mainwindow.cpp" line="68"/>
-        <location filename="../mainwindow.cpp" line="76"/>
-        <location filename="../mainwindow.cpp" line="80"/>
+        <location filename="../src/mainwindow.ui" line="291"/>
+        <location filename="../src/mainwindow.cpp" line="71"/>
+        <location filename="../src/mainwindow.cpp" line="79"/>
+        <location filename="../src/mainwindow.cpp" line="83"/>
         <source>Loading...</source>
         <translation>Φόρτωση...</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="310"/>
+        <location filename="../src/mainwindow.ui" line="310"/>
         <source>This tool lists services and daemons (processes that run in the background) found on this system. Be careful to avoid stopping something that might disrupt a critical component; best to leave it alone if you don&apos;t know what it is.</source>
         <translation>Αυτό το εργαλείο καταγράφει τις υπηρεσίες και τους αυτοματισμούς (διεργασίες που εκτελούνται στο παρασκήνιο) που εντοπίστηκαν σε αυτό το σύστημα. Να είστε προσεκτικοί για να αποφύγετε να διακόψετε κάτι που μπορεί να επηρεάσει ένα κρίσιμο στοιχείο- αν δεν ξέρετε τι είναι, καλύτερα να το αγνοήσετε.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="62"/>
-        <location filename="../mainwindow.cpp" line="392"/>
-        <location filename="../mainwindow.cpp" line="399"/>
-        <location filename="../mainwindow.cpp" line="420"/>
-        <location filename="../mainwindow.cpp" line="429"/>
+        <location filename="../src/mainwindow.cpp" line="65"/>
+        <location filename="../src/mainwindow.cpp" line="396"/>
+        <location filename="../src/mainwindow.cpp" line="403"/>
+        <location filename="../src/mainwindow.cpp" line="426"/>
+        <location filename="../src/mainwindow.cpp" line="435"/>
         <source>Error</source>
         <translation>Σφάλμα</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="63"/>
+        <location filename="../src/mainwindow.cpp" line="66"/>
         <source>Could not determine the init system. This program is supposed to run either with systemd or sysvinit</source>
         <translation>Δεν προσδιορίστηκε το σύστημα εκκίνησης. Αυτό το πρόγραμμα υποτίθεται ότι εκτελείται είτε με systemd είτε με sysvinit</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="144"/>
-        <location filename="../mainwindow.cpp" line="418"/>
+        <location filename="../src/mainwindow.cpp" line="147"/>
+        <location filename="../src/mainwindow.cpp" line="424"/>
         <source>S&amp;tart</source>
         <translation>Εκκί&amp;νηση</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="150"/>
+        <location filename="../src/mainwindow.cpp" line="153"/>
         <source>&amp;Disable at boot</source>
         <translation>Απενε&amp;ργοποίηση στην εκκίνηση</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="355"/>
+        <location filename="../src/mainwindow.cpp" line="358"/>
         <source>%1 total services, %2 currently &lt;font color=&apos;%3&apos;&gt;running&lt;/font&gt;</source>
         <translation>%1 υπηρεσίες συνολικά, %2 &lt;font color=&apos;%3&apos;&gt;σε λειτουργία&lt;/font&gt; αυτή τη στιγμή</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="360"/>
+        <location filename="../src/mainwindow.cpp" line="363"/>
         <source>%1 &lt;font color=&apos;%2&apos;&gt;enabled&lt;/font&gt; at boot, but not running</source>
         <translation>%1 &lt;font color=&apos;%2&apos;&gt;ενεργοποιημένες&lt;/font&gt; στην εκκίνηση, αλλά δεν εκτελούνται</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="375"/>
+        <location filename="../src/mainwindow.cpp" line="378"/>
         <source>About %1</source>
         <translation>Περί του %1</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="376"/>
+        <location filename="../src/mainwindow.cpp" line="379"/>
         <source>Version: </source>
         <translation>Έκδοση: </translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="377"/>
+        <location filename="../src/mainwindow.cpp" line="380"/>
         <source>Service and daemon manager</source>
         <translation>Διαχειριστής υπηρεσιών και διεργασιών</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="379"/>
+        <location filename="../src/mainwindow.cpp" line="382"/>
         <source>Copyright (c) MX Linux</source>
         <translation>Πνευματικά δικαιώματα (c) MX Linux</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="380"/>
+        <location filename="../src/mainwindow.cpp" line="383"/>
         <source>%1 License</source>
         <translation>Άδεια %1</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="392"/>
+        <location filename="../src/mainwindow.cpp" line="396"/>
         <source>Could not enable %1</source>
         <translation>Δεν ήταν δυνατή η ενεργοποίηση του %1</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="396"/>
-        <location filename="../mainwindow.cpp" line="403"/>
-        <location filename="../mainwindow.cpp" line="425"/>
-        <location filename="../mainwindow.cpp" line="434"/>
+        <location filename="../src/mainwindow.cpp" line="400"/>
+        <location filename="../src/mainwindow.cpp" line="407"/>
+        <location filename="../src/mainwindow.cpp" line="431"/>
+        <location filename="../src/mainwindow.cpp" line="440"/>
         <source>Success</source>
         <translation>Επιτυχία</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="396"/>
+        <location filename="../src/mainwindow.cpp" line="400"/>
         <source>%1 was enabled at boot time.</source>
         <translation>Το %1 ενεργοποιήθηκε στην εκκίνηση.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="399"/>
+        <location filename="../src/mainwindow.cpp" line="403"/>
         <source>Could not disable %1</source>
         <translation>Δεν ήταν δυνατή η απενεργοποίηση του %1</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="403"/>
+        <location filename="../src/mainwindow.cpp" line="407"/>
         <source>%1 was disabled.</source>
         <translation>Το %1 απενεργοποιήθηκε.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="410"/>
+        <location filename="../src/mainwindow.cpp" line="415"/>
         <source>%1 Help</source>
         <translation>Βοήθεια %1</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="420"/>
+        <location filename="../src/mainwindow.cpp" line="426"/>
         <source>Could not start %1</source>
         <translation>Δεν μπόρεσε να ξεκινήσει το %1</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="425"/>
+        <location filename="../src/mainwindow.cpp" line="431"/>
         <source>%1 was started.</source>
         <translation>Το %1 ξεκίνησε.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="429"/>
+        <location filename="../src/mainwindow.cpp" line="435"/>
         <source>Could not stop %1</source>
         <translation>Δεν μπόρεσε να σταματήσει το %1</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="434"/>
+        <location filename="../src/mainwindow.cpp" line="440"/>
         <source>%1 was stopped.</source>
         <translation>Το %1 σταμάτησε.</translation>
     </message>
@@ -224,46 +239,46 @@
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../about.cpp" line="70"/>
+        <location filename="../src/about.cpp" line="70"/>
         <source>License</source>
         <translation>Άδεια</translation>
     </message>
     <message>
-        <location filename="../about.cpp" line="71"/>
-        <location filename="../about.cpp" line="81"/>
+        <location filename="../src/about.cpp" line="71"/>
+        <location filename="../src/about.cpp" line="81"/>
         <source>Changelog</source>
         <translation>Αρχείο αλλαγών</translation>
     </message>
     <message>
-        <location filename="../about.cpp" line="72"/>
+        <location filename="../src/about.cpp" line="72"/>
         <source>Cancel</source>
         <translation>Άκυρο</translation>
     </message>
     <message>
-        <location filename="../about.cpp" line="94"/>
+        <location filename="../src/about.cpp" line="94"/>
         <source>&amp;Close</source>
         <translation>&amp;Κλείσιμο</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="74"/>
-        <location filename="../main.cpp" line="82"/>
+        <location filename="../src/main.cpp" line="81"/>
+        <location filename="../src/main.cpp" line="89"/>
         <source>Error</source>
         <translation>Σφάλμα</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="75"/>
+        <location filename="../src/main.cpp" line="82"/>
         <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
         <translation>Φαίνεται ότι έχετε συνδεθεί ως διαχειριστής, αποσυνδεθείτε και συνδεθείτε ως απλός χρήστης για να χρησιμοποιήσετε αυτό το πρόγραμμα.</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="83"/>
+        <location filename="../src/main.cpp" line="90"/>
         <source>You must run this program with admin access.</source>
         <translation>Πρέπει να εκτελέσετε αυτό το πρόγραμμα με πρόσβαση διαχειριστή.</translation>
     </message>
     <message>
-        <location filename="../service.cpp" line="124"/>
+        <location filename="../src/service.cpp" line="150"/>
         <source>Could not find service description</source>
         <translation>Δεν βρέθηκε η περιγραφή της υπηρεσίας</translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+</TS>
